@@ -5,14 +5,19 @@ import (
 	"fmt"
 	"io/ioutil"
 	"path/filepath"
+
+	"github.com/linuxdeepin/dde-api/soundutils"
+	"github.com/linuxdeepin/go-gir/gio-2.0"
 )
 
 type config struct {
-	DesktopLoginEnabled bool
-	Theme               string
-	Card                string
-	Device              string
-	Mute                bool
+	Enabled               bool // 音效总开关
+	DesktopLoginEnabled   bool
+	SystemShutdownEnabled bool
+	Theme                 string
+	Card                  string
+	Device                string
+	Mute                  bool
 }
 
 func getConfigFile(uid int) string {
@@ -29,10 +34,21 @@ func saveUserConfig(uid int, cfg *config) error {
 	return saveConfig(filename, cfg)
 }
 
+var _loadDefaultCfgFromGSettings bool = false
+
 func loadConfig(filename string, cfg *config) error {
-	// default value:
-	cfg.DesktopLoginEnabled = true
-	cfg.Theme = "deepin"
+	if _loadDefaultCfgFromGSettings {
+		// 从 gsettings 获取默认值
+		soundEffectGs := gio.NewSettings("com.deepin.dde.sound-effect")
+		defer soundEffectGs.Unref()
+		appearanceGs := gio.NewSettings("com.deepin.dde.appearance")
+		defer appearanceGs.Unref()
+
+		cfg.Enabled = soundEffectGs.GetBoolean("enabled")
+		cfg.DesktopLoginEnabled = soundEffectGs.GetBoolean(soundutils.EventDesktopLogin)
+		cfg.SystemShutdownEnabled = soundEffectGs.GetBoolean(soundutils.EventSystemShutdown)
+		cfg.Theme = appearanceGs.GetString("sound-theme")
+	}
 
 	data, err := ioutil.ReadFile(filename)
 	if err != nil {
